#[unsafe(no_mangle)]pub unsafe extern "C" fn pqc_format_free(handle: *mut PqcFormatHandle)Expand description
Free a PqcBinaryFormat handle
Safety
Handle must have been allocated by this library and not previously freed
#[unsafe(no_mangle)]pub unsafe extern "C" fn pqc_format_free(handle: *mut PqcFormatHandle)Free a PqcBinaryFormat handle
Handle must have been allocated by this library and not previously freed